package com.burtbeckwith.mvctest.controller;

import java.util.Date;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.springframework.beans.factory.annotation.Required;
import org.springframework.ui.ModelMap;
import org.springframework.web.servlet.ModelAndView;
import org.springframework.web.servlet.mvc.AbstractController;

import com.burtbeckwith.mvctest.service.IBookService;

/**
 * Simple controller that creates a basic model and uses a JSP as its view.
 *
 * @author Burt
 */
public class TestController extends AbstractController {

	private IBookService bookService;

	/**
	 * {@inheritDoc}
	 * @see org.springframework.web.servlet.mvc.AbstractController#handleRequestInternal(
	 * 	javax.servlet.http.HttpServletRequest, javax.servlet.http.HttpServletResponse)
	 */
	@Override
	protected ModelAndView handleRequestInternal(
			final HttpServletRequest request, final HttpServletResponse response) {

		return new ModelAndView("books", new ModelMap()
			.addAttribute("books", bookService.getAllBooks())
			.addAttribute("now", new Date())
		);
	}

	/**
	 * Dependency injection for the book service.
	 * @param service  the service
	 */
	@Required
	public void setBookService(final IBookService service) {
		bookService = service;
	}
}
